<TeXmacs|1.0.7.14>

<style|<tuple|generic|cite-author-year>>

<\body>
  <doc-data|<doc-title|JointSNVMix Software
  Package>|<doc-author-data|<author-name|Andrew Roth>>>

  <section|Introduction>

  JointSNVMix is a suite of tools for identifying somatic mutations in
  matched tumour/normal paired data sequence data. The package consists of
  several models for calling somatic mutations.\ 

  The novel models implemented are JointSNVMix1 and JointSNVMix2. Both models
  implement the same strategy of modeling the joint distribution of data
  generated by the normal and tumour data. They differ in what type of data
  they extract and model from the sequence files.

  <section|Joint Genotype>

  Given tumour-normal paired allelic counts obtained from NGS sequence data
  aligned to the human reference genome, we focus on the problem of
  identifying the <strong|joint-genotype> of the samples at every location in
  the data with coverage.\ 

  For simplicity, and following standard convention, we imagine that each
  position has only two possible alleles, A and B. The allele A indicates
  that the nucleotide at a position matches the reference genome and B
  indicates that the nucleotide is a mismatch. In NGS data we can measure the
  presence of these alleles using binary count data which examines all reads
  at a given site <math|i> and counts the number of matches,
  <math|a<rsup|i>>, and mismatches, <math|b<rsup|i>> <cite|Goya2010>. In
  Figure <reference|counts> we see how this formalism can be extended to
  tumour-normal paired samples.

  <big-figure|<image|figures/counts.svg|309px|467px||>|<label|counts>Schematic
  of how JointSNVMix works. On the top we have the aligned read data. On the
  bottom we show the joint genotype information for the red column which is a
  likely somatic mutation.>

  For a diploid genome we consider all pairs of alleles which gives rise to
  the set, <math|\<cal-G\>=<around*|{|<with|mode|text|AA>,<with|mode|text|AB>,<with|mode|text|BB>|}>>,
  the set of diploid genotypes. Now given two diploid samples the set of
  possible <strong|joint-genotypes> consists of all combinations of diploid
  genotypes which is equivalent to the Cartesian product of <math|\<cal-G\>>
  with itself, i.e. <math|\<cal-G\>\<times\>\<cal-G\>=<around*|{|<around*|(|g<rsub|N>,g<rsub|T>|)>
  : g<rsub|N>,g<rsub|T>\<in\>\<cal-G\>|}>>. We use the convention the normal
  genotype is always the listed first and then the tumour genotype.

  We assume the joint genotype of a given position can be mapped onto the
  more biologically interpretable set of marginal genotypes according to
  Table <reference|joint-genotype>. This can be done by assigning the joint
  genotype to the most probable state, or marginalising together the joint
  genotype probabilities for a given state. As an example of marginalisation
  we compute <math|\<bbb-P\><around*|(|Somatic|)>=\<bbb-P\><around*|(|<around*|(|<with|mode|text|AA>,<with|mode|text|AB>|)>|)>+\<bbb-P\><around*|(|<around*|(|<with|mode|text|AA>,<with|mode|text|BB>|)>|)>>,
  i.e. the sum of probabilities of a wildtype genotype in the normal data and
  a variant genotype in the tumour data.

  <big-table|<tabular*|<tformat|<table|<row|<cell|<math|<rsub|g<rsub|N>>\\<rsup|g<rsub|T>>>>|<cell|AA>|<cell|AB>|<cell|BB>>|<row|<cell|AA>|<cell|Wildtype>|<cell|Somatic>|<cell|Somatic>>|<row|<cell|AB>|<cell|LOH>|<cell|Germline>|<cell|LOH>>|<row|<cell|BB>|<cell|Error>|<cell|Error>|<cell|Germline>>>>>|<label|joint-genotype>Biological
  interpreation of the joint-genotype. Here LOH stands for loss of
  heterozygousity.>

  \;

  <section|JointSNVMix>

  JointSNVMix1 and JointSNVMix2 are generative probabilistic models which
  describe the joint emission of the allelic count data observed at position
  <math|i> in the normal and tumour samples.

  We introduce a random variable <math|G<rsup|i>> as a Multinomial indicator
  vector representing the joint genotype of the samples. More explicitly
  <math|G<rsup|i>=<around*|(|G<rsub|<with|mode|text|AA,AA>><rsup|i>,G<rsub|<with|mode|text|AA,AB>><rsup|i>,\<ldots\>,G<rsub|<with|mode|text|BB,BB>><rsup|i>|)>>
  where <math|G<rsub|g<rsub|N>,g<rsub|T>>=1> if the joint genotype of
  position <math|i> is <math|<around*|(|g<rsub|N>,g<rsub|T>|)>> and
  <math|G<rsub|g<rsub|N>,g<rsub|T>>=0> otherwise. We assume the count data
  from the two samples are <em|jointly> emitted from <math|G<rsup|i>> thus
  capturing correlations between the variables, and allowing statistical
  strength to be borrowed across the samples.

  Given the joint genotype of the sample we model the normal and tumour
  sample as being conditionally independent.

  JointSNVMix1 simply looks at all counts with the required mapping and base
  quality. This data can be summarized by the number of reads matching the
  reference <math|a> and the number of reads not matching the reference
  <math|b>. This data can then be modeled as a mixture of Binomial
  distributions.

  JointSNVMix2 on the other hand explicitly accounts for each bases, read and
  mapping quality and models these using Bernoulli random variables. This
  idea has previously been used in the SNVMix software and references can be
  found in <cite|Goya2010>.

  I will subsequently be refer to both models as JointSNVMix unless the
  distinction is relevant.

  <section|Understanding How JointSNVMix Work>

  <subsection|Intuitive Explanation>

  The intuitive idea being JointSNVMix is that by looking at both the tumour
  and the normal data together we should be better able to identify positions
  which are somatic. The main benefit of the joint modeling approach is that
  JointSNVMix is better able to find shared signals in the normal and tumour,
  which might have been missed if the samples were examined independently.\ 

  One way to understand this is if you imagine having position in the tumour
  with a depth of 30, and it shows 15 matches to the reference and 15
  mis-matches i.e. <math|a<rsub|<with|mode|text|Tumour>>=15>,
  <math|b<rsub|<with|mode|text|Tumour>>=15>. Now suppose we only have depth
  of 5 in the normal and 4 bases match and 1 mismatches i.e.
  <math|a<rsub|<with|mode|text|Normal>>=4>,
  <math|b<rsub|<with|mode|text|Normal>>=1>. The evidence for variant in the
  normal is quite weak, and many callers would be inclined to identify the
  genotype of the normal as homozygous for match allele i.e.
  <math|g<rsub|N>=<with|mode|text|AA>>. They would also likely call the
  tumour heterozygous position i.e. <math|g<rsub|T>=<with|mode|text|AB>>.
  This would lead to a call of somatic mutation at this position.\ 

  However, now imagine we consider the data from both samples together, along
  with the auxiliary information the germline events are quite prevalent
  while somatics are rare. We would likely want to call this position a
  heterozygous germline position since there is strong evidence of
  heterozygous variant in the tumour and some evidence in the normal. Thus
  JointSNVMix would likely assign a higher probability to the joint genotype
  <math|<around*|(|<with|mode|text|AB>,<with|mode|text|AB>|)>> then an
  independent analysis.

  This example demonstrates a basic concept of JointSNVMix, which is that
  information can be shared between samples to better identify germline
  positions. The effect of this is to remove these from the list of predicted
  somatic mutations, reducing the number of false positives.\ 

  Nothing is free however, and there will be a corresponding increase in
  somatic mutations which are missed because they are identified as germline,
  these would be false negatives. In our experiments the reduction in false
  positives tends be much greater than the increase in false negatives. Thus
  on the whole the strategy works quite well.

  <subsection|Best Practices>

  JointSNVMix makes the assumption that the inputted count data is correct,
  except for <strong|random> sequencing and alignment errors. This makes is
  susceptible to <strong|systematic> errors caused by specific sequencing
  technologies and aligners. It is generally a good idea to pre-process the
  data in some way to remove as many of these systematic errors, such as
  poorly mapped regions, obvious sequencing errors such as regions with
  strong strand bias etc. Tools such as GATK can be used to do this step.

  It is highly recommended that the data for the tumour and normal is
  generated in the same way. Ideally the seuencing should be performed under
  exactly the same conditions, and all pre-processing of the data such as
  alignments etc. should be identical. The reason for this is that systematic
  errors in the data will then tend to appear in both files. Hence, if such
  errors create the signature of a variant if one sample, they will likely do
  so in the other. These positions will then be identified as ``germline''
  events, and not somatic events.

  JointSNVMix2 is a little more robust than JointSNVMix1 to some errors,
  because it explicitly models mapping and base quality. Thus we generally
  recommend using JointSNVMix2.

  Both models are highly susceptible to errors in regions of high depth. This
  has to do with the nature of the Binomial/Bernoulli distributions. These
  regions of high depth, or read sinks are often systematic errors which can
  be pre-processed out.

  Pre-processing strategies for use with JointSNMix is something are
  currently exploring, and any feedback would be welcome.

  <subsubsection|LOH>

  Though it is possible to identify LOH using JointSNVMix, we do not
  recommend to do so. The key issue is that LOH can be better inferred using
  models which explicitly account for spatial correlations between sites.
  None of the models in JointSNVMix package account for spatial correlation,
  as they treat the data as being independent.

  The reason for using spatial models such as HMM's for inferring LOH relates
  to the biological mechanisms for creating LOH such as the loss of
  chromosome arms. Methods which ignore this will tend to have a high false
  positive rates.

  <subsection|Results File>

  All models in the JointSNVMix software suite output files in the same
  format. The file has the format 17 columns.

  <\enumerate-numeric>
    <item>chrom - Chromosome the site is on.

    <item>position - 1-based position on the chromosome

    <item>ref_base - Base found in reference genome at this position.

    <item>var_base - Variant base found at this position. If no variant base
    is found this will be N.

    <item>normal_counts_a - Number of read matching ref_base in the normal at
    this position

    <item>normal_counts_b - Number of reads matching var_base in the normal
    at this position.

    <item>tumour_counts_a - Number of read matching ref_base in the tumour at
    this position.

    <item>tumour_counts_b - Number of reads matching var_base in the tumour
    at this position.

    <item>p_AA_AA - Probability of joint genotype (AA, AA). We call this a
    wildtype position.

    <item>p_AA_AB - Probability of joint genotype (AA, AB). This is a somatic
    mutation of one allele.

    <item>p_AA_BB - Probability of joint genotype (AA, BB). This is a somatic
    mutation of both alleles.

    <item> p_AB_AA - Probability of joint genotype (AB, AA). This is a loss
    of heterozygosity (LOH) going back to the reference allele.

    <item>p_AB_AB - Probability of joint genotype (AB, AB). This is a
    germline heterozygous genotype.

    <item>p_AB_BB - Probability of joint genotype (AB, BB). This is LOH going
    to the non-reference allele.

    <item>p_BB_AA - Probability of joint genotype (BB, AA). This is a somatic
    mutation from homozygous in the normal for the non-reference allele to
    homozygous in the tumour for the reference allele. We generally believe
    these to be errors due to the extremely low probability of such events.

    <item>p_BB_AB - Probability of joint genotype (BB, AB).This is a somatic
    mutation from homozygous in the normal for the non-reference allele to
    heterozygous in the tumour. We generally believe these to be errors due
    to the extremely low probability of such events.

    <item>p_AB_BB - Probability of joint genotype (BB,BB). This is germline
    homozygous variant.
  </enumerate-numeric>

  For models which deterministically assign a genotype one of the
  probabilities will be 1, while the rest will be 0.

  <\bibliography|bib|bioinfo|/home/andrew/code/joint_snv_mix/doc/ref.bib>
    <\bib-list|1>
      <bibitem*|Goya et al.(2010)><label|bib-Goya2010>Goya, R.
      <with|font-shape|italic|et<nbsp>al.> (2010) SNVMix: predicting single
      nucleotide variants from next-generation sequencing of tumors.
      <newblock><with|font-shape|italic|Bioinformatics>,
      <with|font-series|bold|26>, 730--736.
    </bib-list>
  </bibliography>
</body>

<\initial>
  <\collection>
    <associate|page-type|letter>
  </collection>
</initial>

<\references>
  <\collection>
    <associate|auto-1|<tuple|1|1>>
    <associate|auto-10|<tuple|4.3|4>>
    <associate|auto-11|<tuple|17|?>>
    <associate|auto-2|<tuple|2|1>>
    <associate|auto-3|<tuple|1|1>>
    <associate|auto-4|<tuple|1|2>>
    <associate|auto-5|<tuple|3|2>>
    <associate|auto-6|<tuple|4|2>>
    <associate|auto-7|<tuple|4.1|2>>
    <associate|auto-8|<tuple|4.2|3>>
    <associate|auto-9|<tuple|4.2.1|3>>
    <associate|bib-Goya2010|<tuple|Goya et al.(2010)|4>>
    <associate|counts|<tuple|1|1>>
    <associate|joint-genotype|<tuple|1|2>>
  </collection>
</references>

<\auxiliary>
  <\collection>
    <\associate|bib>
      Goya2010

      Goya2010

      Goya2010

      Goya2010
    </associate>
    <\associate|figure>
      <tuple|normal|<label|counts>Schematic of how JointSNVMix works. On the
      top we have the aligned read data. On the bottom we show the joint
      genotype information for the red column which is a likely somatic
      mutation.|<pageref|auto-3>>
    </associate>
    <\associate|table>
      <tuple|normal|<label|joint-genotype>Biological interpreation of the
      joint-genotype. Here LOH stands for loss of
      heterozygousity.|<pageref|auto-4>>
    </associate>
    <\associate|toc>
      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|Introduction>
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-1><vspace|0.5fn>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|Joint
      Genotype> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-2><vspace|0.5fn>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|JointSNVMix>
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-5><vspace|0.5fn>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|Understanding
      How JointSNVMix Work> <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-6><vspace|0.5fn>

      <with|par-left|<quote|1.5fn>|Intuitive Explanation
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-7>>

      <with|par-left|<quote|1.5fn>|Best Practices
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-8>>

      <with|par-left|<quote|1.5fn>|Results File
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-9>>

      <vspace*|1fn><with|font-series|<quote|bold>|math-font-series|<quote|bold>|Bibliography>
      <datoms|<macro|x|<repeat|<arg|x>|<with|font-series|medium|<with|font-size|1|<space|0.2fn>.<space|0.2fn>>>>>|<htab|5mm>>
      <no-break><pageref|auto-10><vspace|0.5fn>
    </associate>
  </collection>
</auxiliary>